@@ -1,26 +1,23 @@
-/***************************************************************************
-    begin                : Sat Feb 14 2004
-    copyright            : (C) 2004 by Scott Wheeler
-    email                : wheeler@kde.org
+/**
+ * Copyright (C) 2004 Scott Wheeler <wheeler@kde.org>
+ * Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
+ * Copyright (C) 2008 Michael Pyne <mpyne@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the License, or (at your option) any later
+ * version.
+ *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
-    copyright            : (C) 2007 by Matthias Kretz
-    email                : kretz@kde.org
-
-    copyright            : (C) 2008 by Michael Pyne
-    email                : michael.pyne@kdemail.net
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
-#ifndef PLAYERMANAGER_H
-#define PLAYERMANAGER_H
+#ifndef JUK_PLAYERMANAGER_H
+#define JUK_PLAYERMANAGER_H
 
 #include <QObject>
 
@@ -29,8 +26,6 @@
 #include <Phonon/Global>
 #include <Phonon/Path>
 
-class KSelectAction;
-class StatusLabel;
 class PlaylistInterface;
 class QPixmap;
 
@@ -38,7 +33,6 @@ namespace Phonon
 {
     class AudioOutput;
     class MediaObject;
-    class VolumeFaderEffect;
 }
 
 /**
@@ -52,7 +46,6 @@ class PlayerManager : public QObject
 
 public:
     PlayerManager();
-    virtual ~PlayerManager();
 
     bool playing() const;
     bool paused() const;
@@ -79,10 +72,7 @@ public:
     FileHandle playingFile() const;
     QString playingString() const;
 
-    KSelectAction* outputDeviceSelectAction();
-
     void setPlaylistInterface(PlaylistInterface *interface);
-    void setStatusLabel(StatusLabel *label);
 
     QString randomPlayMode() const;
 
@@ -106,11 +96,10 @@ public slots:
     bool mute();
 
     void setRandomPlayMode(const QString &randomMode);
-    void setCrossfadeEnabled(bool enableCrossfade);
 
 signals:
-    void tick(int time);
-    void totalTimeChanged(int time);
+    void tick(qint64 /* time_msec */);
+    void totalTimeChanged(qint64 /* time_msec */);
     void mutedChanged(bool muted);
     void volumeChanged(float volume);
     void seeked(int newPos);
@@ -123,17 +112,12 @@ signals:
 
 private:
     void setup();
-    void crossfadeToFile(const FileHandle &newFile);
-    void stopCrossfade();
 
 private slots:
-    void slotNeedNextUrl();
     void slotFinished();
     void slotLength(qint64);
     void slotTick(qint64);
     void slotStateChanged(Phonon::State, Phonon::State);
-    /// Updates the GUI to reflect stopped playback if we're stopped at this point.
-    void slotUpdateGuiIfStopped();
     void slotSeekableChanged(bool);
     void slotMutedChanged(bool);
     void slotVolumeChanged(qreal);
@@ -141,18 +125,14 @@ private slots:
 private:
     FileHandle m_file;
     PlaylistInterface *m_playlistInterface;
-    StatusLabel *m_statusLabel;
     bool m_muted;
     bool m_setup;
-    bool m_crossfadeTracks;
 
     static const int m_pollInterval = 800;
 
-    int m_curOutputPath; ///< Either 0 or 1 depending on which output path is in use.
-    Phonon::AudioOutput *m_output[2];
-    Phonon::Path m_audioPath[2];
-    Phonon::MediaObject *m_media[2];
-    Phonon::VolumeFaderEffect *m_fader[2];
+    Phonon::AudioOutput *m_output;
+    Phonon::Path m_audioPath;
+    Phonon::MediaObject *m_media;
 };
 
 #endif
