@@ -168,8 +168,7 @@ public:
      * both PlaylistItems and CollectionListItems.
      */
     virtual PlaylistItem *createItem(const FileHandle &file,
-                                     QTreeWidgetItem *after = 0,
-                                     bool emitChanged = true);
+                                     QTreeWidgetItem *after = nullptr);
 
     /**
      * This is implemented as a template method to allow subclasses to
@@ -177,10 +176,9 @@ public:
      */
     template <class ItemType>
     ItemType *createItem(const FileHandle &file,
-                         QTreeWidgetItem *after = 0,
-                         bool emitChanged = true);
+                         QTreeWidgetItem *after = nullptr);
 
-    virtual void createItems(const PlaylistItemList &siblings, PlaylistItem *after = 0);
+    virtual void createItems(const PlaylistItemList &siblings, PlaylistItem *after = nullptr);
 
     /**
      * This handles adding files of various types -- music, playlist or directory
@@ -215,7 +213,7 @@ public:
     /**
      * Shows column \a c.  If \a updateSearch is true then a signal that the
      * visible columns have changed will be emitted and things like the search
-     * will be udated.
+     * will be updated.
      */
     void showColumn(int c, bool updateSearch = true);
 
@@ -414,6 +412,15 @@ protected:
      */
     void removeFromDisk(const PlaylistItemList &items);
 
+    /**
+     * Adds and removes items from this Playlist as necessary to ensure that
+     * the same items are present in this Playlist as in @p itemList.
+     *
+     * No ordering guarantees are imposed, just that the playlist will have the
+     * same items as in the given list afterwards.
+     */
+    void synchronizeItemsTo(const PlaylistItemList &itemList);
+
     // the following are all reimplemented from base classes
 
     virtual bool eventFilter(QObject *watched, QEvent *e);
@@ -429,6 +436,8 @@ protected:
     virtual void paintEvent(QPaintEvent *pe);
     virtual void resizeEvent(QResizeEvent *re);
 
+    virtual void drawRow(QPainter *p, const QStyleOptionViewItem &option, const QModelIndex &index) const;
+
     virtual void insertItem(QTreeWidgetItem *item);
     virtual void takeItem(QTreeWidgetItem *item);
 
@@ -437,7 +446,7 @@ protected:
     virtual void addColumn(const QString &label, int width = -1);
 
     /**
-     * Do some finial initialization of created items.  Notably ensure that they
+     * Do some final initialization of created items.  Notably ensure that they
      * are shown or hidden based on the contents of the current PlaylistSearch.
      *
      * This is called by the PlaylistItem constructor.
@@ -451,14 +460,14 @@ protected:
     void setDynamicListsFrozen(bool frozen);
 
     template <class ItemType, class SiblingType>
-    ItemType *createItem(SiblingType *sibling, ItemType *after = 0);
+    ItemType *createItem(SiblingType *sibling, ItemType *after = nullptr);
 
     /**
      * As a template this allows us to use the same code to initialize the items
      * in subclasses. ItemType should be a PlaylistItem subclass.
      */
     template <class ItemType, class SiblingType>
-    void createItems(const QList<SiblingType *> &siblings, ItemType *after = 0);
+    void createItems(const QList<SiblingType *> &siblings, ItemType *after = nullptr);
 
 protected slots:
     void slotPopulateBackMenu() const;
@@ -510,7 +519,7 @@ private:
     /**
      * Returns the index of the left most visible column in the playlist.
      *
-     * \see isColumnVisible()
+     * \see isColumnHidden()
      */
     int leftMostVisibleColumn() const;
 
@@ -555,8 +564,8 @@ private:
     /**
      * Used as a helper to implement template<> createItem().  This grabs the
      * CollectionListItem for file if it exists, otherwise it creates a new one and
-     * returns that.  If 0 is returned then some kind of error occurred, such as file not
-     * found and probably nothing should be done with the FileHandle you have.
+     * returns that.  If nullptr is returned then some kind of error occurred,
+     * and you should probably do nothing with the FileHandle you have.
      */
     CollectionListItem *collectionListItem(const FileHandle &file);
 
@@ -729,22 +738,16 @@ QDataStream &operator>>(QDataStream &s, Playlist &p);
 // template method implementations
 
 template <class ItemType>
-ItemType *Playlist::createItem(const FileHandle &file, QTreeWidgetItem *after,
-                               bool emitChanged)
+ItemType *Playlist::createItem(const FileHandle &file, QTreeWidgetItem *after)
 {
     CollectionListItem *item = collectionListItem(file);
     if(item && (!m_members.insert(file.absFilePath()) || m_allowDuplicates)) {
-
-        ItemType *i = after ? new ItemType(item, this, after) : new ItemType(item, this);
+        auto i = new ItemType(item, this, after);
         setupItem(i);
-
-        if(emitChanged)
-            playlistItemsChanged();
-
         return i;
     }
     else
-        return 0;
+        return nullptr;
 }
 
 template <class ItemType, class SiblingType>
